package com.winhc.bigdata.spark.utils

import java.util.Date

import org.apache.spark.sql.SparkSession

import scala.annotation.meta.getter

/**
 * π
 * cid转换
 */

case class CompanyForCidUtils(s: SparkSession, sourceTable: String, cols: Seq[String]) extends LoggingUtils {
  @(transient@getter) val spark: SparkSession = s

  def calc(): Unit = {
    println(s"${this.getClass.getSimpleName} calc start! " + new Date().toString)

    val odsTable = s"ods_$sourceTable"
    val adsTable = s"ads_$sourceTable"
    val companyMapping = "company_name_mapping_pro"
    val ds = BaseUtil.getPartion(odsTable, spark)
    //table字段
    val columns: Seq[String] = spark.table(odsTable).schema.map(_.name).filter(!_.equals("ds"))
    val disCol = cols

    //替换字段
    sql(
      s"""
         |SELECT  ${columns.mkString(",a.")},
         |     coalesce(b.new_cid,a.cid) AS new_cid
         |FROM $odsTable a
         |LEFT JOIN $companyMapping b
         |ON   a.cid = b.cid
         |WHERE a.ds = $ds and a.cid is not null
         |""".stripMargin).dropDuplicates(disCol.:+("new_cid"))
      .createOrReplaceTempView(s"t2")

    sql(s"select ${columns.mkString(",")},new_cid from t2").show(10)

    //写表
    sql(s"insert overwrite table ${adsTable} partition (ds=${ds}) select ${columns.mkString(",")},new_cid from t2")

    println(s"${this.getClass.getSimpleName} calc end! " + new Date().toString)
  }
}